@@ -2,21 +2,21 @@
 #ifndef _GLIBMM_USTRING_H
 #define _GLIBMM_USTRING_H
 
-/* $Id: ustring.h 749 2008-12-10 14:23:33Z jjongsma $ */
+/* $Id$ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -608,6 +608,13 @@ public:
 //! @name Message formatting.
 //! @{
 
+  /* Returns fmt as is, but checks for invalid references in the format string.
+   * @newin2p18
+   */
+  template <class T1>
+  static inline
+  ustring compose(const ustring& fmt);
+
   /*! Substitute placeholders in a format string with the referenced arguments.
    * The template string should be in <tt>qt-format</tt>, that is
    * <tt>"%1"</tt>, <tt>"%2"</tt>, ..., <tt>"%9"</tt> are used as placeholders
@@ -984,43 +991,43 @@ const ustring_Iterator<T> ustring_Iterator<T>::operator--(int)
 
 
 /** @relates Glib::ustring_Iterator */
-template <class T> inline
-bool operator==(const ustring_Iterator<T>& lhs, const ustring_Iterator<T>& rhs)
+inline
+bool operator==(const Glib::ustring::const_iterator& lhs, const Glib::ustring::const_iterator& rhs)
 {
   return (lhs.base() == rhs.base());
 }
 
 /** @relates Glib::ustring_Iterator */
-template <class T> inline
-bool operator!=(const ustring_Iterator<T>& lhs, const ustring_Iterator<T>& rhs)
+inline
+bool operator!=(const Glib::ustring::const_iterator& lhs, const Glib::ustring::const_iterator& rhs)
 {
   return (lhs.base() != rhs.base());
 }
 
 /** @relates Glib::ustring_Iterator */
-template <class T> inline
-bool operator<(const ustring_Iterator<T>& lhs, const ustring_Iterator<T>& rhs)
+inline
+bool operator<(const Glib::ustring::const_iterator& lhs, const Glib::ustring::const_iterator& rhs)
 {
   return (lhs.base() < rhs.base());
 }
 
 /** @relates Glib::ustring_Iterator */
-template <class T> inline
-bool operator>(const ustring_Iterator<T>& lhs, const ustring_Iterator<T>& rhs)
+inline
+bool operator>(const Glib::ustring::const_iterator& lhs, const Glib::ustring::const_iterator& rhs)
 {
   return (lhs.base() > rhs.base());
 }
 
 /** @relates Glib::ustring_Iterator */
-template <class T> inline
-bool operator<=(const ustring_Iterator<T>& lhs, const ustring_Iterator<T>& rhs)
+inline
+bool operator<=(const Glib::ustring::const_iterator& lhs, const Glib::ustring::const_iterator& rhs)
 {
   return (lhs.base() <= rhs.base());
 }
 
 /** @relates Glib::ustring_Iterator */
-template <class T> inline
-bool operator>=(const ustring_Iterator<T>& lhs, const ustring_Iterator<T>& rhs)
+inline
+bool operator>=(const Glib::ustring::const_iterator& lhs, const Glib::ustring::const_iterator& rhs)
 {
   return (lhs.base() >= rhs.base());
 }
@@ -1300,6 +1307,13 @@ public:
   inline const ustring* ptr() const { return &string_; }
 };
 
+template <class T1>
+inline // static
+ustring ustring::compose(const ustring& fmt)
+{
+  return ustring::compose_argv(fmt, 0, 0);
+}
+
 template <class T1>
 inline // static
 ustring ustring::compose(const ustring& fmt, const T1& a1)
