@@ -27,9 +27,10 @@
 #include "shell.h"
 #include "spawn.h"
 #include "thread.h"
-#include "tree.h"
+#include "nodetree.h"
 #include "unicode.h"
 #include "uriutils.h"
+#include "valuearray.h"
 
 extern "C"
 {
